==> client-java-api-3.0.0-sources.jar: io/kubernetes/client/models/V1CapabilitiesFluent.java <==
package io.kubernetes.client.models;

import com.google.gson.annotations.SerializedName;
import io.kubernetes.client.fluent.Fluent;
import java.util.ArrayList;
import java.util.Collection;
import java.util.List;
import java.lang.String;
import java.lang.Boolean;
import io.kubernetes.client.fluent.Predicate;

public interface V1CapabilitiesFluent<A extends V1CapabilitiesFluent<A>> extends Fluent<A>{


    public A addToAdd(int index,String item);
    public A setToAdd(int index,String item);
    public A addToAdd(String... items);
    public A addAllToAdd(Collection<String> items);
    public A removeFromAdd(String... items);
    public A removeAllFromAdd(Collection<String> items);
    public List<String> getAdd();
    public String getAdd(int index);
    public String getFirstAdd();
    public String getLastAdd();
    public String getMatchingAdd(io.kubernetes.client.fluent.Predicate<String> predicate);
    public A withAdd(List<String> add);
    public A withAdd(String... add);
    public Boolean hasAdd();
    public A addToDrop(int index,String item);
    public A setToDrop(int index,String item);
    public A addToDrop(String... items);
    public A addAllToDrop(Collection<String> items);
    public A removeFromDrop(String... items);
    public A removeAllFromDrop(Collection<String> items);
    public List<String> getDrop();
    public String getDrop(int index);
    public String getFirstDrop();
    public String getLastDrop();
    public String getMatchingDrop(io.kubernetes.client.fluent.Predicate<String> predicate);
    public A withDrop(List<String> drop);
    public A withDrop(String... drop);
    public Boolean hasDrop();



}

==> client-java-api-5.0.0-sources.jar: io/kubernetes/client/models/V1CapabilitiesFluent.java <==
package io.kubernetes.client.models;

import java.lang.StringBuffer;
import java.lang.StringBuilder;
import com.google.gson.annotations.SerializedName;
import io.kubernetes.client.fluent.Fluent;
import java.util.ArrayList;
import java.util.Collection;
import java.util.List;
import java.lang.String;
import java.lang.Boolean;
import io.kubernetes.client.fluent.Predicate;

public interface V1CapabilitiesFluent<A extends V1CapabilitiesFluent<A>> extends Fluent<A>{


    public A addToAdd(int index,String item);
    public A setToAdd(int index,String item);
    public A addToAdd(String... items);
    public A addAllToAdd(Collection<String> items);
    public A removeFromAdd(String... items);
    public A removeAllFromAdd(Collection<String> items);
    public List<String> getAdd();
    public String getAdd(int index);
    public String getFirstAdd();
    public String getLastAdd();
    public String getMatchingAdd(io.kubernetes.client.fluent.Predicate<String> predicate);
    public Boolean hasMatchingAdd(io.kubernetes.client.fluent.Predicate<String> predicate);
    public A withAdd(List<String> add);
    public A withAdd(String... add);
    public Boolean hasAdd();
    public A addNewAdd(String arg1);
    public A addNewAdd(StringBuilder arg1);
    public A addNewAdd(StringBuffer arg1);
    public A addToDrop(int index,String item);
    public A setToDrop(int index,String item);
    public A addToDrop(String... items);
    public A addAllToDrop(Collection<String> items);
    public A removeFromDrop(String... items);
    public A removeAllFromDrop(Collection<String> items);
    public List<String> getDrop();
    public String getDrop(int index);
    public String getFirstDrop();
    public String getLastDrop();
    public String getMatchingDrop(io.kubernetes.client.fluent.Predicate<String> predicate);
    public Boolean hasMatchingDrop(io.kubernetes.client.fluent.Predicate<String> predicate);
    public A withDrop(List<String> drop);
    public A withDrop(String... drop);
    public Boolean hasDrop();
    public A addNewDrop(String arg1);
    public A addNewDrop(StringBuilder arg1);
    public A addNewDrop(StringBuffer arg1);



}
